TwFont class abstract

Constructors

TwFont()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

mono TextStyle
no setter
sans TextStyle
no setter
serif TextStyle
no setter

Static Methods

monoFor(TargetPlatform platform) TextStyle
sansFor(TargetPlatform platform) TextStyle
serifFor(TargetPlatform platform) TextStyle