TwSwatchColors class abstract

All of the color swatches defined as a part of Tailwind.

Constructors

TwSwatchColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

amber → const ColorSwatch<int>
Corresponds to --color-amber-*
blue → const ColorSwatch<int>
Corresponds to --color-blue-*
colorList → const Map<String, ColorSwatch<int>>
cyan → const ColorSwatch<int>
Corresponds to --color-cyan-*
emerald → const ColorSwatch<int>
Corresponds to --color-emerald-*
fuchsia → const ColorSwatch<int>
Corresponds to --color-fuchsia-*
gray → const ColorSwatch<int>
Corresponds to --color-gray-*
green → const ColorSwatch<int>
Corresponds to --color-green-*
indigo → const ColorSwatch<int>
Corresponds to --color-indigo-*
lime → const ColorSwatch<int>
Corresponds to --color-lime-*
neutral → const ColorSwatch<int>
Corresponds to --color-neutral-*
orange → const ColorSwatch<int>
Corresponds to --color-orange-*
pink → const ColorSwatch<int>
Corresponds to --color-pink-*
purple → const ColorSwatch<int>
Corresponds to --color-purple-*
red → const ColorSwatch<int>
Corresponds to --color-red-*
rose → const ColorSwatch<int>
Corresponds to --color-rose-*
sky → const ColorSwatch<int>
Corresponds to --color-sky-*
slate → const ColorSwatch<int>
Corresponds to --color-slate-*
stone → const ColorSwatch<int>
Corresponds to --color-stone-*
teal → const ColorSwatch<int>
Corresponds to --color-teal-*
violet → const ColorSwatch<int>
Corresponds to --color-violet-*
yellow → const ColorSwatch<int>
Corresponds to --color-yellow-*
zinc → const ColorSwatch<int>
Corresponds to --color-zinc-*